@@ -235,13 +235,27 @@ impl Bombadil {
 
     /// Enable a dotfile profile by merging its config with the default profile
     pub fn enable_profiles(&mut self, profile_keys: Vec<&str>) -> Result<()> {
-        let profiles: Vec<Profile> = profile_keys
+        let mut profiles: Vec<Profile> = profile_keys
             .iter()
             // unwrap here is safe cause allowed profile keys are checked by clap
             .map(|profile_key| self.profiles.get(&profile_key.to_string()).unwrap())
             .cloned()
             .collect();
 
+        let sub_profiles: Vec<Profile> = profiles
+            .iter()
+            .flat_map(|profile| {
+                profile
+                    .extra_profiles
+                    .iter()
+                    .flat_map(|sub_profile| self.profiles.get(sub_profile))
+                    .collect::<Vec<&Profile>>()
+            })
+            .cloned()
+            .collect();
+
+        profiles.extend(sub_profiles);
+
         // Merge profile dots
         for profile in profiles.iter() {
             profile.dots.iter().for_each(|(key, dot_override)| {
@@ -448,8 +462,7 @@ impl Bombadil {
         let mut ignored: Vec<PathBuf> = self
             .profiles
             .iter()
-            .map(|(_, profile)| profile.dots.get(dot_key))
-            .flatten()
+            .filter_map(|(_, profile)| profile.dots.get(dot_key))
             .filter(|dot| dot.vars.is_some())
             .filter_map(|dot| dot.resolve_var_path(&self.path, origin_source))
             .collect();
@@ -900,6 +913,7 @@ mod tests {
             "profile_one".to_string(),
             Profile {
                 dots: dots_profile_one,
+                extra_profiles: vec![],
                 prehooks: vec![],
                 posthooks: vec![],
                 vars: vec![],
@@ -913,6 +927,7 @@ mod tests {
                 prehooks: vec![],
                 posthooks: vec![],
                 vars: vec![],
+                extra_profiles: vec![],
             },
         );
 
